pub fn extract_managed_resources(
metadata: &CodeGenMetadata,
methods: &[MethodPlan],
) -> Vec<ManagedResource>Expand description
Extract managed resources from service methods, deduplicating by type name.
pub fn extract_managed_resources(
metadata: &CodeGenMetadata,
methods: &[MethodPlan],
) -> Vec<ManagedResource>Extract managed resources from service methods, deduplicating by type name.