pub struct BodyField {
pub name: String,
pub field_type: UnifiedType,
pub repeated: bool,
pub oneof_variants: Option<Vec<OneofVariant>>,
pub documentation: Option<String>,
}Expand description
A body field that should be extracted from the request body
Fields
name: StringField name
field_type: UnifiedTypeParsed type of the body parameter
repeated: boolWhether this field is a repeated (Vec) type
oneof_variants: Option<Vec<OneofVariant>>For oneof fields, the variants with their names and types
documentation: Option<String>Documentation from protobuf field comments
Implementations
Sourceimpl BodyField
impl BodyField
Sourcepub fn is_optional(&self) -> bool
pub fn is_optional(&self) -> bool
Denotes whether this field should be treated as optional in builder APIs.
A field is optional when its UnifiedType.is_optional flag is set, when it is
repeated, or when its base type is Map, Message, or OneOf (complex types
always have a valid default and are therefore optional constructor parameters).