pub struct QueryParam {
pub name: String,
pub field_type: UnifiedType,
pub documentation: Option<String>,
pub resource_reference: Option<ResourceReference>,
}Expand description
A query parameter for HTTP requests
Fields
name: StringParameter name
field_type: UnifiedTypeParsed type of the query parameter
documentation: Option<String>Documentation from protobuf field comments
resource_reference: Option<ResourceReference>Resource reference annotation, if present on the corresponding proto field.
child_typenon-empty: this param scopes a parent of that resource type (e.g.catalog_namewithchild_type = "unitycatalog.io/Schema").r#typenon-empty: this param directly identifies a resource of that type.
Implementations
Sourceimpl QueryParam
impl QueryParam
Sourcepub fn is_optional(&self) -> bool
pub fn is_optional(&self) -> bool
Denotes if the parameter is optional