pub struct CodeGenMetadata {
pub messages: HashMap<String, MessageInfo>,
pub enums: HashMap<String, EnumInfo>,
pub services: HashMap<String, ServiceInfo>,
}Expand description
Collected metadata for code generation
Fields
messages: HashMap<String, MessageInfo>enums: HashMap<String, EnumInfo>services: HashMap<String, ServiceInfo>Implementations
Sourceimpl CodeGenMetadata
impl CodeGenMetadata
Sourcepub fn get_message_fields(&self, type_name: &str) -> Vec<MessageField>
pub fn get_message_fields(&self, type_name: &str) -> Vec<MessageField>
Get message fields for a given type name
Sourcepub fn resource_from_singular(&self, name: &str) -> Option<&ResourceDescriptor>
pub fn resource_from_singular(&self, name: &str) -> Option<&ResourceDescriptor>
Find a resource descriptor whose singular field matches name.
Sourcepub fn resource_from_plural(&self, name: &str) -> Option<&ResourceDescriptor>
pub fn resource_from_plural(&self, name: &str) -> Option<&ResourceDescriptor>
Find a resource descriptor whose plural field matches name.
Sourcepub fn get_resource_descriptor(
&self,
type_name: &str,
) -> Option<&ResourceDescriptor>
pub fn get_resource_descriptor( &self, type_name: &str, ) -> Option<&ResourceDescriptor>
Get resource descriptor by message type name (simple or fully-qualified).