pub enum RenderContext {
Constructor,
Extractor,
QueryExtractor,
Parameter,
ReturnType,
FieldType,
BuilderMethod,
PythonParameter,
NapiParameter,
}Expand description
Context for rendering types in different situations
Variants
Constructor
A constructor (new method) in Rust
Extractor
when extracting from a request inside implementations of FromRequest or FromRequestParts (path params: renders enum as i32 for direct axum::extract::Path deserialization)
QueryExtractor
when building the QueryParams serde struct for query string deserialization (renders enum as its actual Rust type so serde can deserialize from string variant names)
Parameter
Regular parameter type
ReturnType
Return type
FieldType
Field type in a struct
BuilderMethod
Builder method parameter
PythonParameter
Python parameter type (Rust FFI signatures for PyO3 bindings)
NapiParameter
NAPI parameter type (Rust NAPI function signatures for Node.js bindings)